[^:]*: Assembler messages:
[^:]*:\d+: Error: register out of range at operand 2 -- `bfmop4a za0\.s,z1\.h,z16\.h'
[^:]*:\d+: Error: register out of range at operand 2 -- `fmop4a za0\.s,z15\.h,z16\.h'
[^:]*:\d+: Error: register out of range at operand 2 -- `bfmop4a za0\.s,z16\.h,{z16\.h-z17\.h}'
[^:]*:\d+: Error: register out of range at operand 2 -- `fmop4a za0\.s,z17\.h,{z16\.h-z17\.h}'
[^:]*:\d+: Error: start register out of range at operand 2 -- `bfmop4a za0\.s,{z1\.h-z2\.h},z16\.h'
[^:]*:\d+: Error: start register out of range at operand 2 -- `fmop4a za0\.s,{z15\.h-z16\.h},z16\.h'
[^:]*:\d+: Error: start register out of range at operand 2 -- `bfmop4a za0\.s,{z16\.h-z17\.h},{z16\.h-z17\.h}'
[^:]*:\d+: Error: start register out of range at operand 2 -- `fmop4a za0\.s,{z17\.h-z18\.h},{z16\.h-z17\.h}'
[^:]*:\d+: Error: register out of range at operand 3 -- `smop4a za0\.s,z0\.h,z14\.h'
[^:]*:\d+: Error: register out of range at operand 3 -- `smop4a za0\.s,z0\.b,z15\.b'
[^:]*:\d+: Error: register out of range at operand 3 -- `umop4a za0\.s,{z0\.h-z1\.h},z17\.h'
[^:]*:\d+: Error: start register out of range at operand 3 -- `smop4a za0\.s,z0\.h,{z14\.h-z15\.h}'
[^:]*:\d+: Error: start register out of range at operand 3 -- `smop4a za0\.s,z0\.b,{z15\.b-z16\.b}'
[^:]*:\d+: Error: start register out of range at operand 3 -- `umop4a za0\.s,{z0\.h-z1\.h},{z17\.h-z18\.h}'
