.*: Assembler messages:
.*: Warning: unpredictable load of register pair -- `ldap x0,x0,\[x0\]'
.*: Warning: unpredictable load of register pair -- `ldap x0,x0,\[sp\]'
.*: Warning: unpredictable load of register pair -- `ldapp x0,x0,\[x0\]'
.*: Warning: unpredictable load of register pair -- `ldapp x0,x0,\[sp\]'
