.*: Assembler messages:
.*: Error: missing register at operand 2 -- `plbi perme1os'
.*: Error: missing register at operand 2 -- `plbi perme1osnxs'
.*: Error: missing register at operand 2 -- `plbi aside1os'
.*: Error: missing register at operand 2 -- `plbi aside1osnxs'
.*: Error: missing register at operand 2 -- `plbi permae1os'
.*: Error: missing register at operand 2 -- `plbi permae1osnxs'
.*: Error: missing register at operand 2 -- `plbi perme1is'
.*: Error: missing register at operand 2 -- `plbi perme1isnxs'
.*: Error: missing register at operand 2 -- `plbi aside1is'
.*: Error: missing register at operand 2 -- `plbi aside1isnxs'
.*: Error: missing register at operand 2 -- `plbi permae1is'
.*: Error: missing register at operand 2 -- `plbi permae1isnxs'
.*: Error: missing register at operand 2 -- `plbi perme1'
.*: Error: missing register at operand 2 -- `plbi perme1nxs'
.*: Error: missing register at operand 2 -- `plbi aside1'
.*: Error: missing register at operand 2 -- `plbi aside1nxs'
.*: Error: missing register at operand 2 -- `plbi permae1'
.*: Error: missing register at operand 2 -- `plbi permae1nxs'
.*: Error: missing register at operand 2 -- `plbi perme2os'
.*: Error: missing register at operand 2 -- `plbi perme2osnxs'
.*: Error: missing register at operand 2 -- `plbi perme2is'
.*: Error: missing register at operand 2 -- `plbi perme2isnxs'
.*: Error: missing register at operand 2 -- `plbi perme2'
.*: Error: missing register at operand 2 -- `plbi perme2nxs'
.*: Error: missing register at operand 2 -- `plbi perme3os'
.*: Error: missing register at operand 2 -- `plbi perme3osnxs'
.*: Error: missing register at operand 2 -- `plbi perme3is'
.*: Error: missing register at operand 2 -- `plbi perme3isnxs'
.*: Error: missing register at operand 2 -- `plbi perme3'
.*: Error: missing register at operand 2 -- `plbi perme3nxs'
.*: Error: selected processor does not support system register name 'vmalle1os'
.*: Error: selected processor does not support system register name 'vmalle1osnxs'
.*: Error: selected processor does not support system register name 'vmalle1os'
.*: Error: selected processor does not support system register name 'vmalle1osnxs'
.*: Error: selected processor does not support system register name 'vmalle1is'
.*: Error: selected processor does not support system register name 'vmalle1isnxs'
.*: Error: selected processor does not support system register name 'vmalle1is'
.*: Error: selected processor does not support system register name 'vmalle1isnxs'
.*: Error: extraneous register at operand 2 -- `plbi vmalle1,x0'
.*: Error: extraneous register at operand 2 -- `plbi vmalle1nxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi vmalle1,xzr'
.*: Error: extraneous register at operand 2 -- `plbi vmalle1nxs,xzr'
.*: Error: selected processor does not support system register name 'alle2os'
.*: Error: selected processor does not support system register name 'alle2osnxs'
.*: Error: selected processor does not support system register name 'alle2os'
.*: Error: selected processor does not support system register name 'alle2osnxs'
.*: Error: selected processor does not support system register name 'alle1os'
.*: Error: selected processor does not support system register name 'alle1osnxs'
.*: Error: selected processor does not support system register name 'alle1os'
.*: Error: selected processor does not support system register name 'alle1osnxs'
.*: Error: selected processor does not support system register name 'alle2is'
.*: Error: selected processor does not support system register name 'alle2isnxs'
.*: Error: selected processor does not support system register name 'alle2is'
.*: Error: selected processor does not support system register name 'alle2isnxs'
.*: Error: selected processor does not support system register name 'alle1is'
.*: Error: selected processor does not support system register name 'alle1isnxs'
.*: Error: selected processor does not support system register name 'alle1is'
.*: Error: selected processor does not support system register name 'alle1isnxs'
.*: Error: extraneous register at operand 2 -- `plbi alle2,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle2nxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle2,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle2nxs,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle1,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle1nxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle1,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle1nxs,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3os,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3osnxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3os,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3osnxs,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3is,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3isnxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3is,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3isnxs,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3nxs,x0'
.*: Error: extraneous register at operand 2 -- `plbi alle3,xzr'
.*: Error: extraneous register at operand 2 -- `plbi alle3nxs,xzr'
