#as: -defsym __property_zicfiss__=1 -march=rv64i -mabi=lp64
#readelf: -n
#source: property.s

Displaying notes found in: .note.gnu.property
[ 	]+Owner[ 	]+Data size[ 	]+Description
[ 	]+GNU[ 	]+0x00000010[ 	]+NT_GNU_PROPERTY_TYPE_0
[ 	]+Properties: RISC-V AND feature: CFI_SS
